@@ -1,7 +1,7 @@
 use strict;
 package CPAN::Reporter;
 
-our $VERSION = '1.2016';
+our $VERSION = '1.2017';
 
 use Config;
 use Capture::Tiny qw/ capture tee_merged /;
@@ -835,6 +835,13 @@ sub _init_result {
         return;
     }
 
+    if ( $dist->pretty_id =~ m{\w+/Perl6/} ) {
+        $CPAN::Frontend->mywarn(
+            "CPAN::Reporter: Won't report a Perl6 distribution."
+        );
+        return;
+    }
+
     my $result = {
         phase => $phase,
         dist => $dist,
@@ -1577,7 +1584,7 @@ CPAN::Reporter - Adds CPAN Testers reporting to CPAN.pm
 
 =head1 VERSION
 
-version 1.2016
+version 1.2017
 
 =head1 SYNOPSIS
 
